@@ -10,9 +10,9 @@ use crate::Destroyable;
 ///
 /// Fine-grained RAII should be short-lived, making references preferred.
 ///
-/// Note that `'r` can be `'static` when `Resource` is [`ash::Instance`] or [`ash::Device`].
-pub type Guarded<'r, Resource> =
-    GuardedResource<'static, Resource, &'r <Resource as Destroyable>::Destroyer>;
+/// Note that `'d` can be `'static` when `Resource` is [`ash::Instance`] or [`ash::Device`].
+pub type Guarded<'d, Resource> =
+    GuardedResource<'static, Resource, &'d <Resource as Destroyable>::Destroyer>;
 
 /// [`ScopeGuard`](https://docs.rs/scopeguard/1.1.0/scopeguard/struct.ScopeGuard.html) tailored
 /// for Vulkan
@@ -86,7 +86,20 @@ where
         }))
     }
 
-    /// Extract the inner value without destroying it.
+    /// Returns the destroyer smartpointer/reference passed during construction..
+    pub fn destroyer(&self) -> Destroyer
+    where
+        Destroyer: Clone,
+    {
+        self.0.as_ref().unwrap().destroyer.clone()
+    }
+
+    /// Returns the allocation callbacks smartpointer/reference passed during construction..
+    pub fn allocation_callbacks(&self) -> Option<&'alloc_cb vk::AllocationCallbacks> {
+        self.0.as_ref().unwrap().allocation_callbacks
+    }
+
+    /// Extracts the inner value without destroying it.
     ///
     /// ## Note
     ///
